==> fr-aster-9.3.0.1.tbz: aster/STA9.3/bibpyt/Messages/factor.py <==
#@ MODIF factor Messages  DATE 11/02/2008   AUTEUR PELLET J.PELLET 
# -*- coding: iso-8859-1 -*-
#            CONFIGURATION MANAGEMENT OF EDF VERSION
# ======================================================================
# COPYRIGHT (C) 1991 - 2006  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ======================================================================

def _(x) : return x

cata_msg={


#-----------------------------------------------------------------------------------------------
10: _("""
Matrice non factorisable :
  pivot presque nul  la ligne : %(i1)d
  nombre de dcimales perdues  : %(i2)d
"""),

#-----------------------------------------------------------------------------------------------
11: _("""
Matrice non factorisable :
  pivot vraiment nul  la ligne : %(i1)d
"""),

#-----------------------------------------------------------------------------------------------
20: _("""
  -> Matrice non factorisable :
     Le pivot est presque nul  la ligne %(i1)d pour le noeud %(k1)s et
     la composante %(k2)s.
     Pour information, le nombre de dcimales perdues est de %(i2)d.

  -> Conseil & Risque :
     Il s'agit peut etre d'un mouvement de corps rigide mal bloqu.
     Vrifiez les conditions aux limites.
     Si vous faites du contact, il ne faut pas que la
     structure ne "tienne" que par le contact.
"""),

#-----------------------------------------------------------------------------------------------
21: _("""
Matrice non factorisable :
  pivot vraiment nul  la ligne : %(i1)d
  pour le noeud %(k1)s et la composante %(k2)s
"""),


#-----------------------------------------------------------------------------------------------
30: _("""
Matrice non factorisable :
  pivot presque nul  la ligne : %(i1)d
  nombre de dcimales perdues  : %(i2)d
  Il s'agit sans doute d'une relation linaire entre ddls surabondante.
  La liste des noeuds concerns par cette relation est imprime ci-dessus dans le fichier MESSAGE.
"""),

#-----------------------------------------------------------------------------------------------
31: _("""
Matrice non factorisable :
  pivot vraiment nul  la ligne : %(i1)d
  Il s'agit sans doute d'une relation linaire entre ddls surabondante.
  La liste des noeuds concerns par cette relation est imprime ci-dessus dans le fichier MESSAGE.
"""),


#-----------------------------------------------------------------------------------------------
40: _("""
Matrice non factorisable :
  pivot presque nul  la ligne : %(i1)d
  nombre de dcimales perdues  : %(i2)d
  Il s'agit sans doute d'une relation de blocage surabondante.
  blocage concern : %(k4)s
"""),

#-----------------------------------------------------------------------------------------------
41: _("""
Matrice non factorisable :
  pivot vraiment nul  la ligne : %(i1)d
  Il s'agit sans doute d'une relation de blocage surabondante.
  blocage concern : %(k4)s
"""),

#-----------------------------------------------------------------------------------------------
42: _("""
Matrice non factorisable :
  Le solveur MUMPS considre la matrice comme numriquement singulire.
  (Mais il n'en dit pas plus)

Conseil :
  Il s'agit peut-etre d'un manque de conditions aux limites,
  ou au contraire, de redondances entre de trop nombreuses conditions.
"""),
#-----------------------------------------------------------------------------------------------
50: _("""
 Solveur MUMPS :
   -> Vous avez demand comme renumroteur RENUM = '%(k1)s', or MUMPS en a
      utilis un autre.
   -> Risque & Conseil :
      Il se peut que votre version de MUMPS n'ait pas t compile avec
      le support de ce renumroteur. Dans le doute, RENUM='AUTO' permet
      de laisser MUMPS faire le meilleur choix.
 """),
#-----------------------------------------------------------------------------------------------
51: _("""
Solveur MUMPS interdit ici.
Causes possibles :
  - frottement pnalis ou lagrangien (si MUMPS distribu parallle)
"""),

#-----------------------------------------------------------------------------------------------
52: _("""
Solveurs LDLT et MULT_FRONT seuls permis ici.
Causes possibles :
  - STAT_NON_LINE / FLAMBEMENT
"""),

#-----------------------------------------------------------------------------------------------
53: _("""
Solveur MUMPS :
  Mumps manque de mmoire lors de la factorisation de la matrice.
Solution :
  Il faut augmenter la valeur du mot cl  SOLVEUR/PCENT_PIVOT.
Remarque : on a le droit de dpasser la valeur 100.
"""),

#-----------------------------------------------------------------------------------------------
54: _("""
Solveur MUMPS :
  Le solveur Mumps manque de mmoire lors de la factorisation de la matrice.

Solution :
  Il faut augmenter la mmoire accessible  Mumps (et autres programmes hors fortran d'Aster).
  Pour cela, il faut diminuer la mmoire donne  JEVEUX (ASTK : case "dont Aster (Mo)").
"""),

#-----------------------------------------------------------------------------------------------
55: _("""
Solveur MUMPS :
  Problme ou alarme dans le solveur MUMPS.
  Le code retour de mumps (INFOG(1)) est : %(i1)d
Solution :
  Consulter le manuel d'utilisation de Mumps.
  Prvenir l'quipe de dveloppement de Code_Aster.
"""),

#-----------------------------------------------------------------------------------------------
56: _("""
Solveur MUMPS :
  Il ne faut pas utiliser TYPE_RESOL = '%(k1)s'
  Pour une matrice non-symtrique.
Solution :
  Il faut utiliser TYPE_RESOL = 'NONSYM' (ou 'AUTO').
"""),

#-----------------------------------------------------------------------------------------------
57: _("""
Solveur MUMPS :
  La solution du systme linaire est trop imprcise :
  Erreur calcule   : %(r1)g
  Erreur acceptable : %(r2)g   (RESI_RELA)
Solution :
  On peut augmenter la valeur du mot cl SOLVEUR/RESI_RELA.
"""),

#-----------------------------------------------------------------------------------------------
58: _("""
Solveur MUMPS :
  La matrice est numriquement singulire.
Solution :
  Peut tre un problme de modlisation (blocages redondants...)
"""),

#-----------------------------------------------------------------------------------------------
59: _("""
Solveur MUMPS :
  La matrice est dj factorise. On ne fait rien.
Solution :
  Il y a sans doute une erreur de programmation.
  Contactez l'assistance.
"""),

#-----------------------------------------------------------------------------------------------
60: _("""
Solveur MUMPS :
  Limite atteinte : le solveur Mumps est utilis par plus de 5 matrices simultanment.
Solution :
  Il faut corriger le programme (PARAMETER (NMXINS=5) dans amumps.f)
  Contactez l'assistance.
"""),

#-----------------------------------------------------------------------------------------------
61: _("""
Erreur Programmeur lors de la rsolution d'un systme linaire :
 La numrotation des inconnues est incohrente entre la matrice et le second membre.
 Matrice       : %(k1)s
 Second membre : %(k2)s

 Si solveur : 'Feti' : numro du sous-domaine (ou domaine global) : %(i1)d
"""),

#-----------------------------------------------------------------------------------------------
62: _("""
Alarme Solveur MUMPS :
  La procdure de raffinement itratif aurait besoin de plus que les %(i1)d d'itrations
  imposes en dur dans l'appel MUMPS par Code_Aster.
Solution :
  On peut essayer de corriger l'affectation de XMPSK%ICNTL(10) dans AMUMPR/C.F.
  Contactez l'assistance.
"""),

#-----------------------------------------------------------------------------------------------
63: _("""
Information Solveur MUMPS :
  Dsquilibrage de charge maximum suprieur  %(r1)g %% sur au moins une des 6 tapes profiles.
Conseils: Pour optimiser l'quilibrage de votre calcul, vous pouvez essayer
        - d'enlever du modle les mailles qui ne participent pas au calcul,
        - utiliser l'option 'DISTRIBUE_SD' au lieu de 'DISTRIBUE_MAILLE' ou 'CENTRALISE',
        - diminuer le nombre de processeurs utiliss.
"""),

#-----------------------------------------------------------------------------------------------
}

==> fr-aster-9.4.0.2.tbz: aster/STA9.4/bibpyt/Messages/factor.py <==
#@ MODIF factor Messages  DATE 03/11/2008   AUTEUR PELLET J.PELLET 
# -*- coding: iso-8859-1 -*-
#            CONFIGURATION MANAGEMENT OF EDF VERSION
# ======================================================================
# COPYRIGHT (C) 1991 - 2006  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ======================================================================

def _(x) : return x

cata_msg={


#-----------------------------------------------------------------------------------------------
10: _("""
Matrice non factorisable :
  pivot presque nul  la ligne : %(i1)d
  nombre de dcimales perdues  : %(i2)d
"""),

#-----------------------------------------------------------------------------------------------
11: _("""
Matrice non factorisable :
  pivot vraiment nul  la ligne : %(i1)d
"""),

#-----------------------------------------------------------------------------------------------
13: _("""
Solveur FETI :
  Le solveur FETI est impossible dans ce contexte.
Solution :
  Il faut changer de solveur.
"""),


#-----------------------------------------------------------------------------------------------
20: _("""
  -> Matrice non factorisable :
     Le pivot est presque nul  la ligne %(i1)d pour le noeud %(k1)s et
     la composante %(k2)s.
     Pour information, le nombre de dcimales perdues est de %(i2)d.

  -> Conseil & Risque :
     Il s'agit peut etre d'un mouvement de corps rigide mal bloqu.
     Vrifiez les conditions aux limites.
     Si vous faites du contact, il ne faut pas que la
     structure ne "tienne" que par le contact.
"""),

#-----------------------------------------------------------------------------------------------
21: _("""
Matrice non factorisable :
  pivot vraiment nul  la ligne : %(i1)d
  pour le noeud %(k1)s et la composante %(k2)s
"""),

#-----------------------------------------------------------------------------------------------
22: _("""
  -> Matrice non factorisable :
     Le pivot est presque nul  la ligne %(i1)d pour le noeud %(k1)s et
     la composante %(k2)s.
     Pour information, le nombre de dcimales perdues est de %(i2)d.

  -> Conseil & Risque :
     Il s'agit peut etre d'un mouvement de corps rigide mal bloqu.
     Vrifiez les conditions aux limites.
     Si vous faites du contact, il ne faut pas que la
     structure ne "tienne" que par le contact.

     il se peut aussi que ce phnomne soit tout  fait normal avec X-FEM si la fissure passe
     trs prs d'un noeud.
     Si le nombre de dcimal n'est pas trop grand (maxi 10 dcimales)
     vous pouvez relancer le calcul en augmentant le nombre de dcimales perdues autoris :
     mot-cl NPREC dans STAT_NON_LINE/SOLVEUR.

     Sinon, contactez l'quipe de dveloppement.

"""),

#-----------------------------------------------------------------------------------------------
30: _("""
Matrice non factorisable :
  pivot presque nul  la ligne : %(i1)d
  nombre de dcimales perdues  : %(i2)d
  Il s'agit sans doute d'une relation linaire entre ddls surabondante.
  La liste des noeuds concerns par cette relation est imprime ci-dessus dans le fichier MESSAGE.
"""),

#-----------------------------------------------------------------------------------------------
31: _("""
Matrice non factorisable :
  pivot vraiment nul  la ligne : %(i1)d
  Il s'agit sans doute d'une relation linaire entre ddls surabondante.
  La liste des noeuds concerns par cette relation est imprime ci-dessus dans le fichier MESSAGE.
"""),


#-----------------------------------------------------------------------------------------------
40: _("""
Matrice non factorisable :
  pivot presque nul  la ligne : %(i1)d
  nombre de dcimales perdues  : %(i2)d
  Il s'agit sans doute d'une relation de blocage surabondante.
  blocage concern : %(k4)s
"""),

#-----------------------------------------------------------------------------------------------
41: _("""
Matrice non factorisable :
  pivot vraiment nul  la ligne : %(i1)d
  Il s'agit sans doute d'une relation de blocage surabondante.
  blocage concern : %(k4)s
"""),

#-----------------------------------------------------------------------------------------------
42: _("""
Matrice non factorisable :
  Le solveur MUMPS considre la matrice comme numriquement singulire.
  (Mais il n'en dit pas plus)

Conseil :
  Il s'agit peut-etre d'un manque de conditions aux limites,
  ou au contraire, de redondances entre de trop nombreuses conditions.
"""),
#-----------------------------------------------------------------------------------------------
50: _("""
 Solveur MUMPS :
   -> Vous avez demand comme renumroteur RENUM = '%(k1)s', or MUMPS en a
      utilis un autre.
   -> Risque & Conseil :
      Il se peut que votre version de MUMPS n'ait pas t compile avec
      le support de ce renumroteur. Dans le doute, RENUM='AUTO' permet
      de laisser MUMPS faire le meilleur choix.
 """),

#-----------------------------------------------------------------------------------------------
52: _("""
Solveurs LDLT et MULT_FRONT seuls permis ici.
Causes possibles :
  - STAT_NON_LINE / FLAMBEMENT
"""),

#-----------------------------------------------------------------------------------------------
53: _("""
Solveur MUMPS :
  Mumps manque de mmoire lors de la factorisation de la matrice.
Solution :
  Il faut augmenter la valeur du mot cl  SOLVEUR/PCENT_PIVOT.
Remarque : on a le droit de dpasser la valeur 100.
"""),

#-----------------------------------------------------------------------------------------------
54: _("""
Solveur MUMPS :
  Le solveur Mumps manque de mmoire lors de la factorisation de la matrice.

Solution :
  Il faut augmenter la mmoire accessible  Mumps (et autres programmes hors fortran d'Aster).
  Pour cela, il faut diminuer la mmoire donne  JEVEUX (ASTK : case "dont Aster (Mo)") ou bien
  augmenter la mmoire totale (ASTK : case "Mmoire totale (Mo))".
"""),

#-----------------------------------------------------------------------------------------------
55: _("""
Solveur MUMPS :
  Problme ou alarme dans le solveur MUMPS.
  Le code retour de mumps (INFOG(1)) est : %(i1)d
Solution :
  Consulter le manuel d'utilisation de Mumps.
  Prvenir l'quipe de dveloppement de Code_Aster.
"""),

#-----------------------------------------------------------------------------------------------
56: _("""
Solveur MUMPS :
  Il ne faut pas utiliser TYPE_RESOL = '%(k1)s'
  Pour une matrice non-symtrique.
Solution :
  Il faut utiliser TYPE_RESOL = 'NONSYM' (ou 'AUTO').
"""),

#-----------------------------------------------------------------------------------------------
57: _("""
Solveur MUMPS :
  La solution du systme linaire est trop imprcise :
  Erreur calcule   : %(r1)g
  Erreur acceptable : %(r2)g   (RESI_RELA)
Solution :
  On peut augmenter la valeur du mot cl SOLVEUR/RESI_RELA.
"""),

#-----------------------------------------------------------------------------------------------
59: _("""
Solveur MUMPS :
  La matrice est dj factorise. On ne fait rien.
Solution :
  Il y a sans doute une erreur de programmation.
  Contactez l'assistance.
"""),

#-----------------------------------------------------------------------------------------------
60: _("""
Solveur MUMPS :
  Limite atteinte : le solveur Mumps est utilis par plus de 5 matrices simultanment.
Solution :
  Il faut corriger le programme (PARAMETER (NMXINS=5) dans amumps.f)
  Contactez l'assistance.
"""),

#-----------------------------------------------------------------------------------------------
61: _("""
Erreur Programmeur lors de la rsolution d'un systme linaire :
 La numrotation des inconnues est incohrente entre la matrice et le second membre.
 Matrice       : %(k1)s
 Second membre : %(k2)s

 Si solveur : 'Feti' : numro du sous-domaine (ou domaine global) : %(i1)d
"""),

#-----------------------------------------------------------------------------------------------
62: _("""
Alarme Solveur MUMPS :
  La procdure de raffinement itratif aurait besoin de plus que les %(i1)d d'itrations
  imposes en dur dans l'appel MUMPS par Code_Aster.
Solution :
  On peut essayer de corriger l'affectation de XMPSK%ICNTL(10) dans AMUMPR/C.F.
  Contactez l'assistance.
"""),

#-----------------------------------------------------------------------------------------------
63: _("""
Information Solveur MUMPS :
  Dsquilibrage de charge maximum suprieur  %(r1)g %% sur au moins une des 6 tapes profiles.
Conseils: Pour optimiser l'quilibrage de votre calcul, vous pouvez essayer
        - d'enlever du modle les mailles qui ne participent pas au calcul,
        - utiliser l'option 'DISTRIBUE_SD' au lieu de 'DISTRIBUE_MAILLE' ou 'CENTRALISE',
        - diminuer le nombre de processeurs utiliss.
"""),

#-----------------------------------------------------------------------------------------------

64: _("""
Solveur MUMPS :
  Le solveur Mumps manque de mmoire lors de la phase d'analyse de la matrice.

Solution :
  Il faut augmenter la mmoire accessible  Mumps (et autres programmes hors fortran d'Aster).
  Pour cela, il faut diminuer la mmoire donne  JEVEUX (ASTK : case "dont Aster (Mo)") ou bien
  augmenter la mmoire totale (ASTK : case "Mmoire totale (Mo))".
"""),

#-----------------------------------------------------------------------------------------------

65: _("""
Solveur MUMPS :
  Mumps ne peut pas factoriser la matrice  cause d'un dpassement d'entiers.

Solution :
  Si vous utilisez la version squentielle, alors il vous faut passer  la version parallle.
  Si vous utilisez dj la version parallle, alors il faut augmenter le nombre de processeurs
  allous au calcul.
"""),

#-----------------------------------------------------------------------------------------------

66: _("""
Solveur MUMPS :
  Echec de la factorisation OUT-OF-CORE de MUMPS.
  Consulter les  messages dlivrs  par MUMPS.
Conseil: Augmenter  le nombre de processeurs utiliss.
"""),
#-----------------------------------------------------------------------------------------------

67: _("""
Erreur d'utilisation (commande RESOUDRE) :
  La matrice et le second membre fournis  la commande RESOUDRE
  ne sont pas de meme dimension (nombre de ddls).
Conseil: Vrifier la cohrence des arguments MATR et CHAM_NO.
"""),
#-----------------------------------------------------------------------------------------------

68: _("""
Erreur d'utilisation (commande RESOUDRE) :
  La matrice et le second membre fournis  la commande RESOUDRE
  ne sont pas du meme type (rel/complex).
Conseil: Vrifier la cohrence des arguments MATR et CHAM_NO.
"""),
#-----------------------------------------------------------------------------------------------






}
